let
	mozillaOverlay = import (builtins.fetchTarball https://github.com/mozilla/nixpkgs-mozilla/archive/master.tar.gz);
	pkgs = import <nixpkgs> {overlays = [mozillaOverlay];};
in with pkgs;
let
	migen			= callPackage ./nix/migen.nix {};
	openocd			= callPackage ./nix/openocd.nix {};
	rustPlatform	= callPackage ./nix/rustPlatform.nix {};
	itm				= callPackage ./nix/itm.nix {inherit rustPlatform;};

	runOpenOcdBlock = writeShellScriptBin "run-openocd-block" ''
		openocd -f openocd/openocd.cfg
	'';

	openocdFlash = writeShellScriptBin "openocd-flash" ''
	    openocd -f openocd/openocd.cfg -f openocd/$1.cfg
	'';

	publishMqtt = writeShellScriptBin "publish-mqtt" ''
		mosquitto_pub -h localhost -t $1 -m "$2" -d
	'';

in
	stdenv.mkDerivation {
		name = "Humpback-DDS";		
		buildInputs = with rustPlatform.rust; [
			(pkgs.python3.withPackages(ps: [ migen ]))
			pkgs.yosys
			pkgs.nextpnr
			pkgs.icestorm
			pkgs.gdb
			pkgs.mosquitto
			openocd
			rustc
			cargo
			itm
			runOpenOcdBlock
			openocdFlash
			publishMqtt
		];
	}
